import { JSONSchema7 } from 'json-schema';
import { IWidget } from '../FormBuilder.interface';
type StringOnly<T> = T extends string ? T | string : never;
export type WidgetByFormat = {
    default?: IWidget;
} & {
    [key: string]: IWidget;
};
export type JSONSchemaTypeMapper = {
    string?: WidgetByFormat;
    number?: WidgetByFormat;
    integer?: WidgetByFormat;
    boolean?: WidgetByFormat;
    object?: WidgetByFormat;
    array?: WidgetByFormat;
} & {
    [key: string]: WidgetByFormat;
};
export interface CustomJSONSchema<T extends {
    items?: any;
    properties?: any;
    format?: any;
    type?: any;
} = any, M extends JSONSchemaTypeMapper = any> extends JSONSchema7 {
    items?: CustomJSONSchema<T['items'], M>;
    properties?: {
        [Key in keyof T['properties']]: CustomJSONSchema<T['properties'][Key], M>;
    };
    format?: StringOnly<keyof M[T['type']]>;
    ['x-cdp-widget-type']?: string;
    ['x-cdp-enum-mapper']?: {
        [key: string]: string;
    } | Record<string, string>;
    [key: string]: any;
}
export {};
